## spoor

```bash
$ pip install spoor
```

### Configuration
### TODO:

* [ ] Add datadog exporter
* [x] Add group methods by class option
* [ ] Add tracking by import path
* [x] Add `most_common` method for statistics
